package com.zhentao.drug.utils;

public class SnowflakeIdGenerator {
    /*// 起始时间戳 (2020-01-01)
    private final long startTimeStamp = 1577836800000L;

    // 各部分占用位数
    private final long dataCenterIdBits = 5L;
    private final long machineIdBits = 5L;
    private final long sequenceBits = 12L;

    // 最大值
    private final long maxDataCenterId = -1L ^ (-1L << dataCenterIdBits); // 31
    private final long maxMachineId = -1L ^ (-1L << machineIdBits); // 31
    private final long maxSequence = -1L ^ (-1L << sequenceBits); // 4095

    // 位移量
    private final long machineIdShift = sequenceBits;
    private final long dataCenterIdShift = sequenceBits + machineIdBits;
    private final long timestampShift = sequenceBits + machineIdBits + dataCenterIdBits;

    // 数据中心ID和机器ID
    private final long dataCenterId;
    private final long machineId;

    // 序列号和上一次时间戳
    private long sequence = 0L;
    private long lastTimestamp = -1L;

    // 构造函数
    public SnowflakeIdGenerator(long dataCenterId, long machineId) {
        if (dataCenterId > maxDataCenterId || dataCenterId < 0) {
            throw new IllegalArgumentException("DataCenter ID must be between 0 and " + maxDataCenterId);
        }
        if (machineId > maxMachineId || machineId < 0) {
            throw new IllegalArgumentException("Machine ID must be between 0 and " + maxMachineId);
        }

        this.dataCenterId = dataCenterId;
        this.machineId = machineId;
    }

    // 生成下一个ID
    public synchronized long nextId() {
        long currentTimestamp = System.currentTimeMillis();

        // 处理时钟回拨
        if (currentTimestamp < lastTimestamp) {
            throw new RuntimeException("Clock moved backwards. Refusing to generate id for "
                    + (lastTimestamp - currentTimestamp) + " milliseconds");
        }

        if (currentTimestamp == lastTimestamp) {
            sequence = (sequence + 1) & maxSequence;
            if (sequence == 0) {
                // 当前毫秒内序列号用完，等待下一毫秒
                currentTimestamp = waitNextMillis(lastTimestamp);
            }
        } else {
            // 不同毫秒，重置序列号
            sequence = 0L;
        }

        lastTimestamp = currentTimestamp;

        // 按规则组合生成ID
        return ((currentTimestamp - startTimeStamp) << timestampShift) |
                (dataCenterId << dataCenterIdShift) |
                (machineId << machineIdShift) |
                sequence;
    }

    // 等待下一毫秒
    private long waitNextMillis(long lastTimestamp) {
        long timestamp = System.currentTimeMillis();
        while (timestamp <= lastTimestamp) {
            timestamp = System.currentTimeMillis();
        }
        return timestamp;
    }*/
    private final long startTimeStamp = 1609459200000L; // 2021-01-01
    private final long sequenceBits = 10L; // 序列号占10位，范围0-1023
    private final long maxSequence = -1L ^ (-1L << sequenceBits);

    private long sequence = 0L;
    private long lastTimestamp = -1L;

    // 生成10位数字ID（格式：时间戳后7位 + 3位序列号）
    public synchronized String nextId() {
        long currentTimestamp = System.currentTimeMillis() - startTimeStamp;

        if (currentTimestamp < lastTimestamp) {
            throw new RuntimeException("Clock moved backwards.");
        }

        if (currentTimestamp == lastTimestamp) {
            sequence = (sequence + 1) & maxSequence;
            if (sequence == 0) {
                currentTimestamp = waitNextMillis(lastTimestamp);
            }
        } else {
            sequence = 0L;
        }

        lastTimestamp = currentTimestamp;

        // 组合时间戳和序列号，生成10位数字
        // 时间戳取后7位（支持约10年），序列号取3位（每毫秒支持1000个ID）
        long timestampPart = currentTimestamp % 10000000;
        long id = timestampPart * 1000 + sequence;

        return String.format("%010d", id); // 不足10位时前补0
    }

    private long waitNextMillis(long lastTimestamp) {
        long timestamp = System.currentTimeMillis();
        while (timestamp <= lastTimestamp) {
            timestamp = System.currentTimeMillis();
        }
        return timestamp;
    }
}